abacusai.hosted_app — AbacusAI documentation

# abacusai.hosted_app

## Classes

`HostedApp` | Hosted App

## Module Contents

class abacusai.hosted_app.HostedApp(client, hostedAppId=None, deploymentConversationId=None, name=None, createdAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Hosted App

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - hostedAppId (id) – The ID of the hosted app

    - deploymentConversationId (id) – The ID of the deployment conversation

    - name (str) – The name of the hosted app

    - createdAt (str) – The creation timestamp

  hosted_app_id = None
  deployment_conversation_id = None
  name = None
  created_at = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict